Click Based CLI
===============

The command line interface provides a way to execute a handful of
common tasks without touching any Python code. The CLI is implemented using click_.

.. click:: tdub.__main__:cli
   :prog: tdub
   :show-nested:

.. _click: https://click.palletsprojects.com/
